#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_POSMIN_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_POSMIN_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/simd/posmin.hpp>

#endif
